from multiprocessing import Queue
from threading import Thread
import queue
import time
import datetime
import os
from spiderling.listener import Listener
from spiderling.logger import Logger
from spiderling.dispatcher import Dispatcher
import logging
import logging.config
import json
import importlib

FOLDER_LOCATION = os.path.dirname(os.path.abspath(__file__))
FOLDER_LOCATION_LOGS = os.path.join(FOLDER_LOCATION, 'logs')
FOLDER_LOCATION_LOCAL = os.path.join(FOLDER_LOCATION, 'local')


class Spiderling():
    """
    Classe que define o Spiderling
    """
    def __init__(self,
                 dispositivoKonker='',
                 usuarioKonker='',
                 senhaKonker='',
                 lista_acoes=None,
                 intervalo_listening=15,
                 intervalo_health=300,
                 url_konker_pub='http://data.demo.konkerlabs.net:80/pub/',
                 url_konker_sub='http://data.demo.konkerlabs.net:80/sub/',
                 log_settings_path='',
                 settings_file=None):
        """
        Função construtora da Spiderling
        """

        if settings_file:
            settings_file = importlib.import_module(settings_file)

            if 'dispositivoKonker' in settings_file.__dict__ and settings_file.dispositivoKonker != '':
                self.dispositivoKonker = settings_file.dispositivoKonker
            else:
                raise ValueError('dispositivoKonker config variable not set in settings file')

            if 'usuarioKonker' in settings_file.__dict__ and settings_file.usuarioKonker != '':
                self.usuarioKonker = settings_file.usuarioKonker
            else:
                raise ValueError('usuarioKonker config variable not set in settings file')

            if 'senhaKonker' in settings_file.__dict__ and settings_file.senhaKonker != '':
                self.senhaKonker = settings_file.senhaKonker
            else:
                raise ValueError('senhaKonker config variable not set in settings file')

            if 'intervalo_listening' in settings_file.__dict__ and settings_file.intervalo_listening != '':
                self.intervalo_listening = settings_file.intervalo_listening
            else:
                raise ValueError('intervalo_listening config variable not set in settings file')

            if 'intervalo_health' in settings_file.__dict__ and settings_file.intervalo_health != '':
                self.intervalo_health = settings_file.intervalo_health
            else:
                raise ValueError('intervalo_health config variable not set in settings file')

            if 'url_konker_pub' in settings_file.__dict__ and settings_file.url_konker_pub != '':
                self.url_konker_pub = settings_file.url_konker_pub
            else:
                raise ValueError('url_konker_pub config variable not set in settings file')

            if 'url_konker_sub' in settings_file.__dict__ and settings_file.url_konker_sub != '':
                self.url_konker_sub = settings_file.url_konker_sub
            else:
                raise ValueError('url_konker_sub config variable not set in settings file')

            if 'log_settings_path' in settings_file.__dict__ and settings_file.log_settings_path != '':
                self.log_settings_path = settings_file.log_settings_path
            else:
                raise ValueError('log_settings_path config variable not set in settings file')

            if 'lista_acoes' in settings_file.__dict__:
                for acao in settings_file.lista_acoes:
                    if 'nome' not in acao or acao['nome'] == '' and \
                            'tipo_comando' not in acao or acao['tipo_comando'] == '' and \
                            'comando' not in acao or acao['comando'] == '' and \
                            'retorno_padrao' not in acao:
                        raise ValueError('lista_acoes config variable not set properly')
                self.lista_acoes = settings_file.lista_acoes

        else:
            if dispositivoKonker != '':
                self.dispositivoKonker = dispositivoKonker
            else:
                raise ValueError('dispositivoKonker variable cannot be empty')

            if usuarioKonker != '':
                self.usuarioKonker = usuarioKonker
            else:
                raise ValueError('usuarioKonker variable cannot be empty')

            if senhaKonker != '':
                self.senhaKonker = senhaKonker
            else:
                raise ValueError('senhaKonker variable cannot be empty')

            if intervalo_listening != '':
                self.intervalo_listening = intervalo_listening
            else:
                raise ValueError('intervalo_listening variable cannot be empty')

            if intervalo_health != '':
                self.intervalo_health = intervalo_health
            else:
                raise ValueError('intervalo_health variable cannot be empty')

            if url_konker_pub != '':
                self.url_konker_pub = url_konker_pub
            else:
                raise ValueError('url_konker_pub variable cannot be empty')

            if url_konker_sub != '':
                self.url_konker_sub = url_konker_sub
            else:
                raise ValueError('url_konker_sub variable cannot be empty')

            if log_settings_path != '':
                self.log_settings_path = log_settings_path
            else:
                raise ValueError('log_settings_path variable cannot be empty')

            if lista_acoes:
                for acao in lista_acoes:
                    if 'nome' not in acao or acao['nome'] == '' and \
                            'tipo_comando' not in acao or acao['tipo_comando'] == '' and \
                            'comando' not in acao or acao['comando'] == '' and \
                            'retorno_padrao' not in acao:
                        raise ValueError('lista_acoes config variable not set properly')
                self.lista_acoes = lista_acoes

        self.setup_logging(default_path=self.log_settings_path)
        self._logger = logging.getLogger(__name__)

        self.__logger = Logger(self.dispositivoKonker, self.usuarioKonker, self.senhaKonker, self.url_konker_pub)
        self.__listener = Listener(self.usuarioKonker, self.senhaKonker, self.url_konker_sub, self.__logger)
        self.__dispatcher = Dispatcher(self.__logger, self.lista_acoes)

        self.tarefas_para_executar = Queue()
        self.processos_tarefas = []

        self.__data_hora_listening = datetime.datetime.now() - datetime.timedelta(seconds=self.intervalo_listening)
        self.__data_hora_health = datetime.datetime.now() - datetime.timedelta(seconds=self.intervalo_health)

    def setup_logging(self, default_path=os.path.join(FOLDER_LOCATION_LOGS, 'logging.json'), default_level=logging.INFO, env_key='LOG_CFG'):
        """
        Função que executa a configuração de logs do Spiderling
        """
        path = default_path
        value = os.getenv(env_key, None)
        if value:
            path = value
        if os.path.exists(path):
            with open(path, 'rt') as f:
                config = json.load(f)
                for key, handler in config['handlers'].items():
                    if 'filename' in handler:
                        try:
                            os.mkdir('logs')
                        except OSError:
                            pass
                        handler['filename'] = os.path.join('logs', handler['filename'])

            logging.config.dictConfig(config)
        else:
            logging.basicConfig(level=default_level)

    def thread_health(self):
        """
        Função que realiza o disparo da thread de health do dispositivo
        """
        if (datetime.datetime.now() > self.__data_hora_health):
            self.__logger.registrarHealth()
            self.__data_hora_health = datetime.datetime.now() + datetime.timedelta(seconds=self.intervalo_health)

    def tem_comando(self):
        """
        Função que valida se tem comando de acordo com o ultimo executado
        """
        if (datetime.datetime.now() > self.__data_hora_listening):
            self.__listener.tem_comando(self.tarefas_para_executar)
            self.__data_hora_listening = datetime.datetime.now() + datetime.timedelta(seconds=self.intervalo_listening)

    def executa_tarefas(self):
        """
        Função que valida se existe tarefa de acordo com a fila interna
        """
        def executa_tarefa(tarefa, processos_tarefas):
            self._logger.info(f'Tarefa Encontrada: {tarefa["acao"]}')
            processo_tarefa = Thread(target=self.__dispatcher.executarComando, args=(tarefa['acao'], tarefa['id'], tarefa['registra_execucao']))
            processos_tarefas.append((processo_tarefa, tarefa['acao']))
            processo_tarefa.daemon = True
            processo_tarefa.start()

        try:
            tarefa = self.tarefas_para_executar.get_nowait()
        except queue.Empty:
            pass
        else:
            if tarefa['tipo_execucao'] == 'sequencial':
                for tarefa_processada in self.processos_tarefas:
                    processo, acao = tarefa_processada
                    if processo.is_alive() and tarefa['acao'] == acao:
                        print(f'Ja tem uma tarefa Viva dessa ação: {acao}')
                        self.tarefas_para_executar.put(tarefa)
                        break
                else:
                    executa_tarefa(tarefa, self.processos_tarefas)
            else:
                executa_tarefa(tarefa, self.processos_tarefas)

    def rodar(self):
        """
        Função que realiza o start das funções: thread_health, tem_comando e executa_tarefas
        """
        thread_health = None
        thread_listener = None
        thread_execute = None
        while True:
            # Health
            if not thread_health or not thread_health.is_alive():
                thread_health = Thread(target=self.thread_health)
                thread_health.daemon = True
                thread_health.start()

            # Tem Comando
            if not thread_listener or not thread_listener.is_alive():
                thread_listener = Thread(target=self.tem_comando)
                thread_listener.daemon = True
                thread_listener.start()

            # Executa Tarefas
            if not thread_execute or not thread_execute.is_alive():
                thread_execute = Thread(target=self.executa_tarefas)
                thread_execute.daemon = True
                thread_execute.start()

            time.sleep(1)



import logging
import requests


class Listener():
    """
    Classe que define o Listener que recebe os comandos da Konker
    """

    def __init__(self, usuarioKonker, senhaKonker, url_konker_sub, logger):
        """
        Função construtora da classe Listener
        """
        self.__logger = logger
        self._logger = logging.getLogger(__name__)
        self.usuarioKonker = usuarioKonker
        self.senhaKonker = senhaKonker
        self.url_konker_sub = url_konker_sub
        self._logger.info("carregando listener")

    def tem_comando(self, tarefas_para_executar):
        """
        Função que valida se tem comando no dispositivo e autentica o usuario na Konker
        """
        self._logger.info('Comando tem_comando inicializado')

        url = f'{self.url_konker_sub}{self.usuarioKonker}/cmd'
        headers = {'content-type': 'application/json', 'Accept': 'application/json'}
        auth = (self.usuarioKonker, self.senhaKonker)
        try:
            comando = requests.get(url, headers=headers, auth=auth).json()
        except Exception:
            pass
        else:
            if comando:
                if 'maestro' in comando[0]['meta']['incoming']['deviceId'] and \
                        comando[0]['meta']['outgoing']['channel'] == 'cmd' and \
                        comando[0]['data']['type'] == 'execution':
                    tarefa_dict = {
                        'acao': comando[0]['data']['action'],
                        'id': comando[0]['data']['id'],
                        'registra_execucao': True,
                        'tipo_execucao': comando[0]['data'].get('tipo_execucao', 'sequencial')
                    }
                    self.__logger.registrarCiencia(tarefa_dict['acao'], tarefa_dict['id'])
                    tarefas_para_executar.put(tarefa_dict)

        self._logger.info("Comando tem_comando finalizado")
        return comando



import logging
import datetime
import subprocess as sp


class Dispatcher():
    """
    Classe que define o Dispatcher que envia os comandos para a Konker
    """
    def __init__(self, logger, lista_acoes):
        """
        Função construtora da classe Dispatcher
        """
        self.__logger = logger
        self._logger = logging.getLogger(__name__)
        self._logger.info("Carregando dispatcher")
        self.lista_acoes = lista_acoes

    def executarComando(self, nome_acao, id, registra_execucao=True):
        """
        Função que executa e registra a execução na Konker
        """
        for acao in self.lista_acoes:
            if acao['nome'] == nome_acao:
                tipo_retorno_padrao = acao['retorno_padrao']
                sucesso = True
                retorno_stdout = ''
                retorno_stderr = ''
                retorno_code = -999
                mensagem = ''
                duracao = 0  # deverá ser calculado para envio na mensagem de sucesso
                duracao = datetime.datetime.now()

                self._logger.info(f"Comando {acao['nome']} inicializado")

                if acao['tipo_comando'] == 'script':
                    retorno_execucao = sp.run([acao['comando']], capture_output=True, universal_newlines=True)
                    retorno_code = retorno_execucao.returncode
                    retorno_stdout = retorno_execucao.stdout
                    retorno_stderr = retorno_execucao.stderr
                elif acao['tipo_comando'] == 'funcao_python':
                    try:
                        retorno_execucao = acao['comando']()
                    except Exception as exc:
                        retorno_code = -999
                        retorno_stderr = f'Erro ao executar funcao: {acao["nome"]} erro: {exc}'
                        retorno_stdout = f'Erro ao executar funcao: {acao["nome"]} erro: {exc}'
                    else:
                        retorno_code = 0
                        retorno_stderr = ''
                        retorno_stdout = retorno_execucao

                self._logger.debug(f'RetornoOut: {retorno_stdout}\nRetornoErr: {retorno_stderr}\nRetornoCode: {retorno_code}')
                self._logger.info(f"Comando {acao['nome']} finalizado")
                try:
                    # registro de logs de execução, ignorar se o próprio serviço enviar estes logs
                    # tratar as mensages de retorno para identificar se houve erro
                    duracao = (datetime.datetime.now() - duracao).total_seconds()
                    if registra_execucao:
                        if retorno_code == 0:
                            # registrar log de sucesso
                            status = 'sucesso'
                            if tipo_retorno_padrao:
                                mensagem = f'Comando {nome_acao} finalizado com {status} duracao: {duracao}'
                            else:
                                mensagem = retorno_stdout
                            self.__logger.registrarExecucao(nome_acao, id, duracao, mensagem, False, 0)
                            self._logger.info(f"Ação {nome_acao} executada com sucesso")
                        else:
                            # registrar log de erro
                            status = 'falha'
                            codigo_erro = retorno_code
                            mensagem = f'Comando {nome_acao} finalizado com {status} duracao: {duracao}\nErro: {retorno_stderr}'
                            self.__logger.registrarExecucao(nome_acao, id, duracao, mensagem, True, codigo_erro)
                            sucesso = False
                            self._logger.info(f"Ação {nome_acao} falhou. Erro {str(codigo_erro)} - {mensagem}")
                        self.__logger.registrar_report(id, mensagem)
                    return sucesso
                except Exception as e:
                    self._logger.error(f'Erro: {str(e)}')
                    return False



import json
import platform
import logging
import requests
from spiderling.sistema import Sistema


class Logger():
    """
    Classe Logger que define os loggers da Konker
    """
    def __init__(self, dispositivoKonker, usuarioKonker, senhaKonker, url_konker_pub):
        """
        Função construtora da classe Logger
        """
        self._logger = logging.getLogger(__name__)
        self.dispositivoKonker = dispositivoKonker
        self.usuarioKonker = usuarioKonker
        self.senhaKonker = senhaKonker
        self.url_konker_pub = url_konker_pub

    def registrarHealth(self):
        """
        Função que realiza o registro do log do Health
        """
        self._logger.info("Comando registraHealth inicializado")
        try:
            sistema = Sistema()
            memoria_perc, memoria_usada = sistema.pegarMemoria()
            swap_perc, swap_usada = sistema.pegarSwap()
            disco = sistema.pegarDiscos()
            # disco = 'N/D - Windows'
            hostname = platform.uname()[1]  # os.uname()[1]
            ip = sistema.pegarIPs()
            # timestamp = datetime.datetime.now().timestamp()
            url = self.url_konker_pub + self.usuarioKonker + "/health"
            headers = {'content-type': 'application/json', 'Accept': 'application/json'}
            auth = (self.usuarioKonker, self.senhaKonker)

            # ## GERAL
            msg = {
                "id": self.dispositivoKonker,
                "health": 1,
                "host": {
                    "name": hostname,
                    "ip": ip,
                    "memory": {
                        "perc": memoria_perc,
                        "mb": memoria_usada
                    },
                    "cpu": sistema.pegarCPU(),
                    "swap": {
                        "perc": swap_perc,
                        "mb": swap_usada
                    },
                    "disks": disco
                }
            }

            requests.post(url, headers=headers, auth=auth, data=json.dumps(msg))

            self._logger.info("Comando registraHealth finalizado")
            return True
        except Exception as e:
            self._logger.error(f'erro: {str(e)}')
            return e

    def registrarExecucao(self, nome_operacao, id, duracao, mensagem, erro, codigo_erro):
        """
        Função que realiza o registro da execução da operação
        """
        self._logger.info("Comando registraExecucao inicializado")
        try:
            url = self.url_konker_pub + self.usuarioKonker + "/log"
            headers = {'content-type': 'application/json', 'Accept': 'application/json'}
            auth = (self.usuarioKonker, self.senhaKonker)

            # ## GERAL
            if not erro:
                msg = {"action": nome_operacao, "id": id, "status": 'sucess', "message": mensagem, "duration": duracao, }
            else:
                msg = {"action": nome_operacao, "id": id, "status": 'failure', "message": str(f'error : {str(codigo_erro)} - {mensagem}')}
            requests.post(url, headers=headers, auth=auth, data=json.dumps(msg))

            self._logger.info("Comando registraExecucao finalizado")
            return True
        except Exception as e:
            self._logger.error(f'erro: {str(e)}')
            return e

    def registrarCiencia(self, nome_operacao, id):
        """
        Função que registra a confirmação de recebimento do comando
        """
        self._logger.info("Comando registraCiencia inicializado")
        try:
            url = f'{self.url_konker_pub}{self.usuarioKonker}/ack'
            headers = {'content-type': 'application/json', 'Accept': 'application/json'}
            auth = (self.usuarioKonker, self.senhaKonker)

            # ## GERAL
            msg = {'type': 'ack', "action": nome_operacao, "id": id}
            requests.post(url, headers=headers, auth=auth, data=json.dumps(msg))

            self._logger.info("Comando registraCiencia finalizado")
            return True
        except Exception as e:
            self._logger.error(f'erro: {str(e)}')
            return e

    def registrar_report(self, id, msg_report):
        """
        Função que registra a mensagem de report
        """
        self._logger.info("Comando registraReport inicializado")
        try:
            url = f'{self.url_konker_pub}{self.usuarioKonker}/report'
            headers = {'content-type': 'application/json', 'Accept': 'application/json'}
            auth = (self.usuarioKonker, self.senhaKonker)

            # ## GERAL
            msg = {'type': 'report', 'id': id, 'msg': msg_report}
            requests.post(url, headers=headers, auth=auth, data=json.dumps(msg))

            self._logger.info("Comando registraReport finalizado")
            return True
        except Exception as e:
            self._logger.error(f'erro: {str(e)}')
            return e



import datetime
import time
import platform
import psutil
import netifaces
import os


class Sistema:
    """
    Classe que define o Sistema
    """

    def pegarSistema(self):
        """
        Função que coleta e retorna as informações do Sistema
        """
        resposta = 'Sistema: \n'
        resposta += f'OS: {platform.system()} - {platform.release()}\n'
        resposta += f'Máquina: {platform.node()} - {platform.machine()}\n'
        resposta += f'Uptime: {str(datetime.datetime.now() - datetime.datetime.fromtimestamp(psutil.boot_time()))}\n\n'
        resposta += f'{self.pegarUptime()}\n\n'

        resposta += 'Uso: \n'
        resposta += f'CPU: {str(psutil.cpu_percent())}%\n'
        resposta += f'RAM: {str(psutil.virtual_memory().percent)}% de {str(round(psutil.virtual_memory().total / (10**9), 2))} Giga \n'
        resposta += f'SWAP: {str(psutil.swap_memory().percent)}% de {str(round(psutil.swap_memory().total / (10**9), 2))} Giga \n'
        resposta += 'Discos: \n'
        resposta += f'{self.pegarDiscosTexto()} \n'

        resposta += 'Temperatura: \n'
        if ('armv7' in platform.machine()):
            res = os.popen('/opt/vc/bin/vcgencmd measure_temp').readline()
            res = res.replace("temp=", "").replace("C \n", " ºC")
            resposta += f'CPU: {res}'
        else:
            temps = psutil.sensors_temperatures()
            chaves = set(temps.keys())

            for chave in chaves:
                resposta += chave + '\n'
                if chave in temps:
                    for entrada in temps[chave]:
                        resposta += f'{entrada.label or chave}: {entrada.current}°C (pico={entrada.high}°C, crítica={entrada.critical}°C) \n'
        return resposta

    def pegarApp(self):
        """
        Função que realiza a coleta das informações do App
        """
        resposta = 'Uso Vovô bot: \n'
        pid = os.getpid()
        processo = psutil.Process(pid)
        resposta += f'PID: {str(pid)}\n'
        resposta += f'CPU: {str(processo.cpu_percent())}%\n'
        resposta += f'Memória: {str(round(processo.memory_percent(), 2))}% de {str(round(psutil.virtual_memory().total / (10**9), 2))} Giga \n'
        resposta += f'Uptime: {str(datetime.datetime.now() - datetime.datetime.fromtimestamp(processo.create_time()))} \n\n'

        return resposta

    def pegarCPUProcesso(self):
        """
        Função que coleta e retorna o percentual de processo de CPU
        """
        pid = os.getpid()
        processo = psutil.Process(pid)
        perc = round(processo.cpu_percent(), 2)
        return perc

    def pegarMemoriaProcesso(self):
        """
        Função que coleta e retorna o percentual de processo e de uso da Memoria
        """
        pid = os.getpid()
        processo = psutil.Process(pid)
        perc = round(processo.memory_percent() / (10**6), 2)
        usage = round(((psutil.virtual_memory().total / (10**6)) * processo.memory_percent()) / 100, 2)
        return perc, usage

    def pegarCPU(self):
        """
        Função que retorna o percentual de utilização do CPU
        """
        perc = round(psutil.cpu_percent(), 2)
        return perc

    def pegarMemoria(self):
        """
        Função que retorna o percentual e uso da memoria
        """
        perc = round(psutil.virtual_memory().percent, 2)
        usage = round(((psutil.virtual_memory().total / (10**6)) * psutil.virtual_memory().percent) / 100, 2)
        return perc, usage

    def pegarSwap(self):
        """
        Função que retorna o percentual e uso da memoria swap
        """
        perc = round(psutil.swap_memory().percent, 2)
        usage = round(psutil.swap_memory().used / (10**6), 2)
        return perc, usage

    def pegarIPs(self):
        """
        Função que coleta e retorna os IPs
        """
        interfaces = netifaces.interfaces()
        for i in interfaces:
            if i == 'lo':
                continue
            iface = netifaces.ifaddresses(i).get(netifaces.AF_INET)
            if iface is not None:
                return iface[0]['addr']

    def pegarDiscosTexto(self):
        """
        Função que coleta e retorna as informações do disco
        """
        resposta = ''
        # disk.device para pegar o nome mesmo /dev/sdaX
        for disk in psutil.disk_partitions(all=False):
            resposta += str(disk.mountpoint) + ': ' + str(psutil.disk_usage(disk.mountpoint).percent) + '% de ' + str(round(psutil.disk_usage(disk.mountpoint).total / (10**9), 2)) + ' Gb \n'

        return resposta

    def pegarDiscos(self):
        """
        Função que coleta e retorna as informações de disco
        """
        resposta = []
        # disk.device para pegar o nome mesmo /dev/sdaX
        for disk in psutil.disk_partitions(all=False):
            if disk.opts == 'cdrom':
                continue
            # print("Mountpoint: ", disk.mountpoint)
            resposta.append({disk.mountpoint: {"perc": psutil.disk_usage(disk.mountpoint).percent, "gb": round(psutil.disk_usage(disk.mountpoint).used / (10**9), 2)}})

        return resposta

    def pegarUptime(self):
        """
        Função que retorna o tempo da atividade
        """
        minute = 60
        hour = minute * 60
        day = hour * 24

        d = h = m = 0

        s = int(time.time()) - int(psutil.boot_time())

        d = s / day
        s -= d * day
        h = s / hour
        s -= h * hour
        m = s / minute
        s -= m * minute

        uptime = ""
        if d > 1:
            uptime = f"{d} dias, "
        elif d == 1:
            uptime = "1 dia, "

        return f'{str(uptime)} {h}{m:.2f}{s:.2f}'



from setuptools import setup, find_packages

from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file # Detalhamento do pacote 
try:
    with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
        long_description = f.read()
except:
    long_description = ''

setup(
    # Ver PEP 426 (name)
    # Iniciar ou terminar com letra ou número
    # Nome do seu pacote
    name='spiderling',

    # Ver PEP 440
    # O formato pode ser assim:

    # 1.2.0.dev1  # Development release
    # 1.2.0a1     Alpha Release
    # 1.2.0b1     Beta Release
    # 1.2.0rc1    Release Candidate
    # 1.2.0       Final Release
    # 1.2.0.post1 Post Release
    # 15.10       Date based release
    # 23          Serial release
    # Versao do pacote
    version='1.0.0a1',
    # Se a versão ainda é compativel com o Python utilizado
    # Mudanças que tem no programa, mas a versão anterior ainda é compativel
    # Correções de erro e bugs, atualização

    description='Spiderling Analytics',  # Decrição curta que ficará no rótulo quando pesquisar o pacote
    long_description=long_description,  # arquivo DESCRIPTION.rst

    # Detalhes do Autor
    author='Equipe Analytics',
    author_email='analytics@inmetrics.com.br',

    # Choose your license
    license='GPLv3',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Utilities',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.7',
    ],

    # What does your project relate to?
    keywords='orchestration',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # Se quiser excluir algum pacote que eseteja no seu projeto coloque na lista abaixo
    packages=find_packages(exclude=['logs', 'local']),

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['requests>=2.22.0', 'psutil>=5.6.3', 'netifaces>=0.10.9'],
    setup_requires=['wheel'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #     'data': ['dados.json'],
    # },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('','')]

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    # entry_points={
        # 'console_scripts': [
            # 'sample=sample:main',
        # ],
    # },
)
